@@ -1,25 +1,17 @@
 #' Is increasing
 #'
-#' \code{i_is_increasing} tests if band values are increasing
+#' \code{i_is_increasing} tests if numerical values are increasing
 #'
 #' Many transform functions can only (or at least should only) be applied to
-#' spectra with monotonically varying (very likely increasing) band values.
-#' \code{i_is_increasing} tests that case and may throw an error
-#' or return the boolean result from the test.
+#' spectra with increasing band values. \code{i_is_increasing} tests for that.
 #'
 #' @param x bands
-#' @param stop boolean. Throw error if test fails? Defaults to TRUE
-#' @param call boolean. If stop = TRUE, should the function call be printed?
 #' @return boolean
 #'
 #' @author Jose Eduardo Meireles
 #' @keywords internal
-i_is_increasing = function(x, stop = TRUE, call = FALSE){
-    y = all(diff(x) >= 0.0)
-    if( !y && stop){
-        stop("band values must be strictly increasing. You probably need to run `match_overlap` first", call. = call)
-    }
-    y
+i_is_increasing = function(x){
+    all(diff(x) > 0.0)
 }
 
 
@@ -325,34 +317,3 @@ i_mav = function(x, n = 3, sides = 2){
     stats::filter(x, rep( (1/n), n), sides = sides)
 }
 
-
-
-#' Pairwise index combinations
-#'
-#' \code{i_index_pairwise_combn} returns the split pairwise combination of idxs
-#' in a matrix
-#'
-#' @param n number of indices
-#' @return list of matrices. For each focal index up to n - 1, a matrix with the
-#' other indexes it interacts with (2nd col) and the "absolute position" of that
-#' pairwise interaction (1st column) is returned.
-#'
-#' @author Jose Eduardo Meireles
-#' @keywords internal
-i_index_pairwise_combn = function(n){
-
-    if( ! i_is_whole(n) | n < 2 ){
-        stop("n must be an integer > 1")
-    }
-
-    focal_seq = seq.int(1, n - 1)
-    focal_idx = rep.int(focal_seq, rev(focal_seq))
-
-    iter_seq  = seq.int(2, n)
-    iter_idx  = unlist(sapply(iter_seq, function(x){ seq.int(x, n)} ))
-
-    pos_idx   = seq.int(along.with = iter_idx)
-
-    pcomb = data.frame("pos" = pos_idx,  "iter" = iter_idx, check.names = FALSE)
-    split(pcomb, focal_idx)
-}
